@@ -24,7 +24,7 @@ def get_deploy_params(connection_string, id_project):
 
     cursor = conn.cursor()
     cursor.execute('''select project_path, a.server,deploy_user from projects a 
-                    inner join servers b on a.server=b.server
+                    inner join servers b on a.server=b.host
                    WHERE project_id=%s''', [id_project])
     row = cursor.fetchone()
     conn.close()
